@@ -106,7 +106,7 @@ public class GDE {
 	private static boolean									isWithUi													= false;
 
 	// ****** begin global constants section *******
-	public static final String							VERSION														= "Version 3.9.4"; // check device update list in settings getServiceUpdateList()																						//$NON-NLS-1$
+	public static final String							VERSION														= "Version 3.9.5"; // check device update list in settings getServiceUpdateList()																						//$NON-NLS-1$
 	public static final int									VERSION_NUMBER										= GDE.VERSION.contains("beta") 
 															? Integer.parseInt(GDE.VERSION.substring(8, 8+5).replace(GDE.STRING_DOT, GDE.STRING_EMPTY)) - 1
 															: Integer.parseInt(GDE.VERSION.substring(8, 8+5).replace(GDE.STRING_DOT, GDE.STRING_EMPTY));
@@ -522,8 +522,9 @@ public class GDE {
 				}
 			}
 
-			//special handling replacing device XML without schema update
-			//Settings.getInstance().checkUpdateDeviceProperties(Settings.getDevicesPath());
+			//special handling replacing device XML without schema update, manual update is required for beta builds
+			if (!GDE.VERSION.contains("beta"))
+				Settings.getInstance().checkUpdateDeviceProperties(Settings.getDevicesPath());
 
 			// list system properties
 			StringBuilder sb = new StringBuilder().append("Environment : \n"); //$NON-NLS-1$
