@@ -453,7 +453,8 @@ public class DeviceJavaSerialCommPortImpl extends DeviceCommPort implements IDev
 
 		try {
 			if (this.jsApplication != null) this.jsApplication.setSerialRxOn();
-			wait4Bytes(bytes, timeout_msec - (timeout_msec / 5));
+			if (!GDE.IS_MAC)
+				wait4Bytes(bytes, timeout_msec - (timeout_msec / 5));
 
 
 			while (bytes != readBytes && timeOutCounter-- > 0) {
@@ -909,7 +910,7 @@ public class DeviceJavaSerialCommPortImpl extends DeviceCommPort implements IDev
 
 	/**
 	 * function to close the serial port
-	 * this is done within a tread since the port can't close if it stays open for a long time period ??
+	 * this is done within a thread since the port can't close if it stays open for a long time period ??
 	 */
 	@Override
 	public synchronized void close() {
