@@ -1,6 +1,7 @@
 package gde.comm;
 
 import java.io.IOException;
+import java.io.UnsupportedEncodingException;
 import java.nio.ByteBuffer;
 import java.nio.ByteOrder;
 import java.nio.IntBuffer;
@@ -31,6 +32,7 @@ import javax.usb.event.UsbPipeErrorEvent;
 import javax.usb.event.UsbPipeListener;
 
 import org.usb4java.BufferUtils;
+import org.usb4java.ConfigDescriptor;
 import org.usb4java.Context;
 import org.usb4java.Device;
 import org.usb4java.DeviceDescriptor;
@@ -53,6 +55,7 @@ import gde.log.Level;
 import gde.messages.MessageIds;
 import gde.messages.Messages;
 import gde.ui.DataExplorer;
+import gde.ui.dialog.LibUsbDeviceSelectionDialog;
 import gde.ui.dialog.UsbDeviceSelectionDialog;
 import gde.utils.WaitTimer;
 
@@ -235,6 +238,21 @@ public class DeviceUsbPortImpl extends DeviceCommPort implements IDeviceCommPort
 		return findDevices(services.getRootUsbHub(), vendorId, productId);
 	}
 
+	/**
+	 * find USB device to be identified by vendor ID and product ID
+	 * @param vendorId
+	 * @param productId
+	 * @param productString
+	 * @return
+	 * @throws UsbException
+	 */
+	@Override
+	public Set<UsbDevice> findUsbDevices(final short vendorId, final short productId, final String productString) throws UsbException {
+		usbDevices.clear();
+		UsbServices services = UsbHostManager.getUsbServices();
+		return findDevices(services.getRootUsbHub(), vendorId, productId, productString);
+	}
+
 	/**
 	 * find USB device starting from hub (root hub)
 	 * @param hub
@@ -267,6 +285,46 @@ public class DeviceUsbPortImpl extends DeviceCommPort implements IDeviceCommPort
 		return usbDevices;
 	}
 
+	/**
+	 * find USB device starting from hub (root hub)
+	 * @param hub
+	 * @param vendorId
+	 * @param productId
+	 * @param productString
+	 * @return
+	 */
+	@Override
+	public Set<UsbDevice> findDevices(final UsbHub hub, final short vendorId, final short productId, final String productString) {
+		for (Object tmpDevice : hub.getAttachedUsbDevices()) {
+			if (tmpDevice instanceof UsbDevice) {
+				UsbDevice usbDevice = (UsbDevice) tmpDevice;
+				if (log.isLoggable(Level.FINER)) {
+					log.log(Level.FINER, usbDevice.toString());
+					log.log(Level.FINER, usbDevice.getUsbDeviceDescriptor().toString());
+				}
+				UsbDeviceDescriptor desc = usbDevice.getUsbDeviceDescriptor();
+				String deviceProductString = GDE.STRING_EMPTY;
+				try {
+					deviceProductString = usbDevice.getString(desc.iProduct());
+				}
+				catch (UnsupportedEncodingException | UsbDisconnectedException | UsbException e) {
+					log.log(Level.WARNING, e.getMessage(), e);	
+				}
+				if (desc.idVendor() == vendorId && desc.idProduct() == productId && productString.equals(deviceProductString)) {
+					if (log.isLoggable(Level.FINE)) {
+						log.log(Level.FINE, usbDevice.toString());
+						log.log(Level.FINE, usbDevice.getUsbDeviceDescriptor().toString());
+					}
+					usbDevices.add(usbDevice);
+				}
+				else if (usbDevice.isUsbHub()) {
+					usbDevices.addAll(findDevices((UsbHub) usbDevice, vendorId, productId));
+				}
+			}
+		}
+		return usbDevices;
+	}
+
 	public Set<Device> findDevices(final short vendorId, final short productId, final String productString) throws LibUsbException {
 		libUsbDevices.clear();
 		// Read the USB device list
@@ -372,8 +430,12 @@ public class DeviceUsbPortImpl extends DeviceCommPort implements IDeviceCommPort
 						handle = null;
 					}
 
+					// Dump the device descriptor
 					log.log(Level.INFO, descriptor.dump(handle));
 
+					// Dump all configuration descriptors
+					dumpConfigurationDescriptors(libUsbDevice, descriptor.bNumConfigurations());
+
 					// Close the device if it was opened
 					if (handle != null) {
 						LibUsb.close(handle);
@@ -385,6 +447,42 @@ public class DeviceUsbPortImpl extends DeviceCommPort implements IDeviceCommPort
 			LibUsb.freeDeviceList(list, true);
 		}
 	}
+	/**
+   * Dumps all configuration descriptors of the specified device. Because
+   * libusb descriptors are connected to each other (Configuration descriptor
+   * references interface descriptors which reference endpoint descriptors)
+   * dumping a configuration descriptor also dumps all interface and endpoint
+   * descriptors in this configuration.
+   * 
+   * @param device
+   *            The USB device.
+   * @param numConfigurations
+   *            The number of configurations to dump (Read from the device
+   *            descriptor)
+   */
+	public static void dumpConfigurationDescriptors(final Device device, final int numConfigurations) {
+		for (byte i = 0; i < numConfigurations; i += 1) {
+			final ConfigDescriptor descriptor = new ConfigDescriptor();
+			final int result = LibUsb.getConfigDescriptor(device, i, descriptor);
+			if (result < 0) {
+				log.log(Level.SEVERE, new LibUsbException("Unable to read config descriptor", result).getMessage());
+			}
+			else {
+				try {
+					log.log(Level.INFO, descriptor.dump().replaceAll("(?m)^", "  "));
+				}
+				finally {
+					// Ensure that the config descriptor is freed
+					try {
+						LibUsb.freeConfigDescriptor(descriptor);
+					}
+					catch (Exception e) {
+						// ignore
+					}
+				}
+			}
+		}
+	}
 
 	/**
 	 * dump required information for a USB device with known product ID and
@@ -443,23 +541,45 @@ public class DeviceUsbPortImpl extends DeviceCommPort implements IDeviceCommPort
 		
 		byte ifaceId = activeDevice.getUsbInterface();
 		UsbInterface usbInterface = null;
-		Set<UsbDevice> myLsbDevices = findUsbDevices(activeDevice.getUsbVendorId(), activeDevice.getUsbProductId());
-		if (myLsbDevices.size() == 0) {
+		Set<UsbDevice> myUsbDevices;
+		if (activeDevice.getUsbProductString() == null || activeDevice.getUsbProductString().equalsIgnoreCase(GDE.STRING_EMPTY)) {
+			myUsbDevices = findUsbDevices(activeDevice.getUsbVendorId(), activeDevice.getUsbProductId());
+		} else {
+			myUsbDevices = findUsbDevices(activeDevice.getUsbVendorId(), activeDevice.getUsbProductId(), activeDevice.getUsbProductString());
+		}
+		if (myUsbDevices.size() == 0) {
 			this.usbApplication.openMessageDialog(Messages.getString(MessageIds.GDE_MSGE0050));
-		} else if (myLsbDevices.size() == 1) {
-			for (UsbDevice usbDevice : myLsbDevices) {
+		} else if (myUsbDevices.size() == 1) {
+			for (UsbDevice usbDevice : myUsbDevices) {
 				if (usbDevice == null) 
 					throw new UsbException(Messages.getString(gde.messages.MessageIds.GDE_MSGE0050));
 				usbInterface = claimUsbInterface(usbDevice, ifaceId);
 			}
-		} else {
-			for (UsbDevice usbDevice : myLsbDevices) {
-				UsbInterface tmpUsbInterface = ((UsbConfiguration) usbDevice.getUsbConfigurations().get(0)).getUsbInterface(ifaceId);
-				if (tmpUsbInterface!= null && !(tmpUsbInterface.isActive() || tmpUsbInterface.isClaimed())) {
-					usbInterface = claimUsbInterface(usbDevice, ifaceId);
-					break;
+		} else { //myUsbDevices.size() > 1
+			Map<String, UsbDevice> fondUsbDevices = new HashMap<String, UsbDevice>();
+			for (UsbDevice usbDevice : myUsbDevices) {
+				try {
+					String usbDeviceString = usbDevice.getProductString() + " S/N " + usbDevice.getSerialNumberString();
+					fondUsbDevices.put(usbDeviceString, usbDevice);
+				}
+				catch (UnsupportedEncodingException | UsbDisconnectedException | UsbException e) {
+					// TODO Auto-generated catch block
+					e.printStackTrace();
 				}
 			}
+			UsbDevice selUsbDevice = null;
+			if (fondUsbDevices.size() > 1 && selUsbDevice == null) {
+				//several identical USB HID  found, manual select usbDevice
+				selUsbDevice = (UsbDevice) new UsbDeviceSelectionDialog(fondUsbDevices).open();
+				usbInterface = claimUsbInterface(selUsbDevice, ifaceId);
+			}
+			else if (fondUsbDevices.size() > 1 && selUsbDevice != null) {
+				//several identical USB HID  found, selected usbDevice available for this GDE instance
+				usbInterface = claimUsbInterface(selUsbDevice, ifaceId);
+			}
+			else
+				throw new UsbException(String.format("%s\n===>>>  %s", Messages.getString(MessageIds.GDE_MSGE0050), activeDevice.getUsbProductString()));
+
 		}
 		if (usbInterface == null) {
 			throw new UsbException(Messages.getString(gde.messages.MessageIds.GDE_MSGE0050));
@@ -518,15 +638,14 @@ public class DeviceUsbPortImpl extends DeviceCommPort implements IDeviceCommPort
 				}
 				String descriptorString = descriptor.dump(handle);
 				if (descriptorString.contains("iProduct") && descriptorString.contains(activeDevice.getUsbProductString()) && descriptorString.contains("iSerial")) {
-					String usbDeviceString = descriptorString.substring(descriptorString.lastIndexOf("Junsi"), descriptorString.indexOf("USB HID") + 7) 
-							+ " SN/" + descriptorString.substring(descriptorString.indexOf("iSerial") + 27, descriptorString.indexOf("iSerial") + 37);
+					String usbDeviceString = LibUsb.getStringDescriptor(handle, descriptor.iProduct()) + " S/N " + LibUsb.getStringDescriptor(handle, descriptor.iSerialNumber());
 					myUsbDevices.put(usbDeviceString, libUsbDevice);
 				}				
 				LibUsb.close(handle);
 			}
 			if (myUsbDevices.size() > 0 && selectedUsbDevice == null) {
 				//several identical USB HID  found, manual select usbDevice
-				selectedUsbDevice = (Device) new UsbDeviceSelectionDialog(myUsbDevices).open();
+				selectedUsbDevice = (Device) new LibUsbDeviceSelectionDialog(myUsbDevices).open();
 				claimLibUsbDevice(selectedUsbDevice, libUsbDeviceHandle, ifaceId);
 			}
 			else if (myUsbDevices.size() > 0 && selectedUsbDevice != null) {
@@ -579,7 +698,7 @@ public class DeviceUsbPortImpl extends DeviceCommPort implements IDeviceCommPort
 	 */
 	private UsbInterface claimUsbInterface(UsbDevice usbDevice, byte ifaceId) throws UsbClaimException, UsbException {
 		UsbInterface usbInterface = ((UsbConfiguration) usbDevice.getUsbConfigurations().get(0)).getUsbInterface(ifaceId);
-		log.log(Level.FINE, usbInterface.toString());
+		log.log(Level.INFO, usbInterface.toString());
 		if (GDE.IS_LINUX) {
 			usbInterface.claim(new UsbInterfacePolicy() {
 				@Override
