@@ -34,6 +34,7 @@ import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.layout.RowData;
 import org.eclipse.swt.layout.RowLayout;
 import org.eclipse.swt.widgets.Composite;
+import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Event;
 import org.eclipse.swt.widgets.Slider;
 import org.eclipse.swt.widgets.Text;
@@ -47,7 +48,7 @@ public class ParameterConfigControl {
 	final Composite			baseComposite;
 	final CLabel				nameLabel, descriptionLabel;
 	final Text					text;
-	final Color					textColor					= SWTResourceManager.getColor(SWT.COLOR_BLACK);
+	final Color					textColor					= GDE.isSystemDarkTheme ? SWTResourceManager.getColor(SWT.COLOR_WHITE) : SWTResourceManager.getColor(SWT.COLOR_BLACK);
 	final Color					textWarningColor	= SWTResourceManager.getColor(SWT.COLOR_RED);
 	final Slider				slider;
 
@@ -120,6 +121,7 @@ public class ParameterConfigControl {
 			this.nameLabel.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
 			this.nameLabel.setText(parameterName);
 			this.nameLabel.setBackground(parent.getBackground());
+			this.nameLabel.setForeground(DataExplorer.getInstance().COLOR_BLACK);
 		}
 		{
 			this.text = new Text(this.baseComposite, SWT.CENTER | SWT.BORDER);
@@ -129,7 +131,8 @@ public class ParameterConfigControl {
 			this.text.setLayoutData(textLData);
 			this.text.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
 			this.text.setEditable(isTextValueEditable);
-			this.text.setBackground(SWTResourceManager.getColor(isTextValueEditable ? SWT.COLOR_WHITE : SWT.COLOR_WIDGET_LIGHT_SHADOW));
+			this.text.setBackground(GDE.isSystemDarkTheme ? SWTResourceManager.getColor(isTextValueEditable ? SWT.COLOR_GRAY : SWT.COLOR_WIDGET_DARK_SHADOW) 
+			: SWTResourceManager.getColor(isTextValueEditable ? SWT.COLOR_WHITE : SWT.COLOR_WIDGET_LIGHT_SHADOW));
 			if (isTextValueEditable) {
 				this.text.addVerifyListener(new VerifyListener() {
 					@Override
@@ -184,6 +187,7 @@ public class ParameterConfigControl {
 			this.descriptionLabel.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
 			this.descriptionLabel.setText(parameterDescription);
 			this.descriptionLabel.setBackground(parent.getBackground());
+			this.descriptionLabel.setForeground(DataExplorer.getInstance().COLOR_BLACK);
 		}
 		{
 			RowData sliderLData = new RowData();
@@ -281,6 +285,7 @@ public class ParameterConfigControl {
 			this.nameLabel.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
 			this.nameLabel.setText(parameterName);
 			this.nameLabel.setBackground(parent.getBackground());
+			this.nameLabel.setForeground(DataExplorer.getInstance().COLOR_BLACK);
 		}
 		{
 			this.text = new Text(this.baseComposite, SWT.CENTER | SWT.BORDER);
@@ -290,7 +295,8 @@ public class ParameterConfigControl {
 			this.text.setLayoutData(textLData);
 			this.text.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
 			this.text.setEditable(isTextValueEditable);
-			this.text.setBackground(SWTResourceManager.getColor(isTextValueEditable ? SWT.COLOR_WHITE : SWT.COLOR_WIDGET_LIGHT_SHADOW));
+			this.text.setBackground(GDE.isSystemDarkTheme ? SWTResourceManager.getColor(isTextValueEditable ? SWT.COLOR_GRAY : SWT.COLOR_WIDGET_DARK_SHADOW)
+				:	SWTResourceManager.getColor(isTextValueEditable ? SWT.COLOR_WHITE : SWT.COLOR_WIDGET_LIGHT_SHADOW));
 			this.text.setForeground(textColor);
 			if (isTextValueEditable) {
 				this.text.addVerifyListener(new VerifyListener() {
@@ -351,6 +357,7 @@ public class ParameterConfigControl {
 			this.descriptionLabel.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
 			this.descriptionLabel.setText(parameterDescription);
 			this.descriptionLabel.setBackground(parent.getBackground());
+			this.descriptionLabel.setForeground(DataExplorer.getInstance().COLOR_BLACK);
 		}
 		{
 			RowData sliderLData = new RowData();
@@ -431,6 +438,7 @@ public class ParameterConfigControl {
 			this.nameLabel.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
 			this.nameLabel.setText(parameterName);
 			this.nameLabel.setBackground(parent.getBackground());
+			this.nameLabel.setForeground(DataExplorer.getInstance().COLOR_BLACK);
 		}
 		{
 			this.text = new Text(this.baseComposite, SWT.CENTER | SWT.BORDER);
@@ -440,7 +448,8 @@ public class ParameterConfigControl {
 			this.text.setLayoutData(textLData);
 			this.text.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
 			this.text.setEditable(isTextValueEditable);
-			this.text.setBackground(SWTResourceManager.getColor(isTextValueEditable ? SWT.COLOR_WHITE : SWT.COLOR_WIDGET_LIGHT_SHADOW));
+			this.text.setBackground(GDE.isSystemDarkTheme ? SWTResourceManager.getColor(isTextValueEditable ? SWT.COLOR_GRAY : SWT.COLOR_WIDGET_DARK_SHADOW)
+				: SWTResourceManager.getColor(isTextValueEditable ? SWT.COLOR_WHITE : SWT.COLOR_WIDGET_LIGHT_SHADOW));
 			if (isTextValueEditable) {
 				this.text.addVerifyListener(new VerifyListener() {
 					@Override
@@ -486,6 +495,7 @@ public class ParameterConfigControl {
 			this.descriptionLabel.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
 			this.descriptionLabel.setText(parameterDescription);
 			this.descriptionLabel.setBackground(parent.getBackground());
+			this.descriptionLabel.setForeground(DataExplorer.getInstance().COLOR_BLACK);
 		}
 		{
 			RowData sliderLData = new RowData();
@@ -546,6 +556,7 @@ public class ParameterConfigControl {
 			this.nameLabel.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
 			this.nameLabel.setText(parameterName);
 			this.nameLabel.setBackground(parent.getBackground());
+			this.nameLabel.setForeground(DataExplorer.getInstance().COLOR_BLACK);
 		}
 		{
 			this.text = new Text(this.baseComposite, SWT.CENTER | SWT.BORDER);
@@ -555,7 +566,8 @@ public class ParameterConfigControl {
 			this.text.setLayoutData(textLData);
 			this.text.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
 			this.text.setEditable(false);
-			this.text.setBackground(SWTResourceManager.getColor(SWT.COLOR_WIDGET_LIGHT_SHADOW));
+			this.text.setBackground(GDE.isSystemDarkTheme ? SWTResourceManager.getColor(SWT.COLOR_WIDGET_DARK_SHADOW)
+			: SWTResourceManager.getColor(SWT.COLOR_WIDGET_LIGHT_SHADOW));
 		}
 		{
 			this.descriptionLabel = new CLabel(this.baseComposite, SWT.LEFT);
@@ -566,6 +578,7 @@ public class ParameterConfigControl {
 			this.descriptionLabel.setFont(SWTResourceManager.getFont(GDE.WIDGET_FONT_NAME, GDE.WIDGET_FONT_SIZE, SWT.NORMAL));
 			this.descriptionLabel.setText(parameterDescription);
 			this.descriptionLabel.setBackground(parent.getBackground());
+			this.descriptionLabel.setForeground(DataExplorer.getInstance().COLOR_BLACK);
 		}
 		{
 			RowData sliderLData = new RowData();
