@@ -18,28 +18,31 @@
 ****************************************************************************************/
 package gde.ui.dialog;
 
+import java.util.Map;
+
+import javax.usb.UsbDevice;
+
+import org.eclipse.swt.SWT;
+import org.eclipse.swt.events.SelectionAdapter;
+import org.eclipse.swt.events.SelectionEvent;
+import org.eclipse.swt.layout.RowData;
+import org.eclipse.swt.layout.RowLayout;
+import org.eclipse.swt.widgets.Button;
+import org.eclipse.swt.widgets.Combo;
+import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Dialog;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Shell;
-import org.usb4java.Device;
 
 import gde.messages.MessageIds;
 import gde.messages.Messages;
 import gde.ui.DataExplorer;
 
-import org.eclipse.swt.widgets.Combo;
-
-import java.util.Map;
-
-import org.eclipse.swt.SWT;
-import org.eclipse.swt.events.SelectionAdapter;
-import org.eclipse.swt.events.SelectionEvent;
-
 public class UsbDeviceSelectionDialog extends Dialog {
 
-	Map<String, Device> usbDevices;
-	protected Device	result;
-	protected Shell		shell;
+	Map<String, UsbDevice> 	usbDevices;
+	protected UsbDevice			result;
+	protected Shell					shell;
 
 	/**
 	 * Create the dialog.
@@ -56,10 +59,10 @@ public class UsbDeviceSelectionDialog extends Dialog {
 	 * @param parent
 	 * @param style
 	 */
-	public UsbDeviceSelectionDialog(Map<String, Device> usbDevices) {
+	public UsbDeviceSelectionDialog(Map<String, UsbDevice> fondUsbDevices) {
 		super(DataExplorer.getInstance().getShell(), SWT.DIALOG_TRIM | SWT.PRIMARY_MODAL);
 		setText(Messages.getString(MessageIds.GDE_MSGW0049));
-		this.usbDevices = usbDevices;
+		this.usbDevices = fondUsbDevices;
 	}
 
 	/**
@@ -84,20 +87,37 @@ public class UsbDeviceSelectionDialog extends Dialog {
 	 * Create contents of the dialog.
 	 */
 	private void createContents() {
-		shell = new Shell(getParent(), getStyle());
-		shell.setSize(350, 100);
+		shell = new Shell(getParent(), SWT.DIALOG_TRIM);
+		shell.setSize(350, 130);
 		shell.setText(getText());
+		RowLayout rowLayout = new RowLayout(SWT.VERTICAL);
+		rowLayout.center = true;
+		rowLayout.marginLeft = 10;
+    rowLayout.marginTop = 10;
+    rowLayout.marginRight = 10;
+    rowLayout.marginBottom = 10;
+		shell.setLayout(rowLayout);
 		
 		Combo combo = new Combo(shell, SWT.NONE);
-		combo.setBounds(10, 20, 325, 28);
 		combo.setItems(usbDevices.keySet().toArray(new String[usbDevices.size()]));
 		combo.select(0);
-		combo.addSelectionListener(new SelectionAdapter() {
+		combo.setLayoutData(new RowData(340, 30));
+		
+		new Composite(shell, SWT.NONE).setLayoutData(new RowData(340, 10));
+		
+		Button closeButton = new Button(shell, SWT.BORDER);
+		closeButton.setText("OK");
+		closeButton.setLayoutData(new RowData(80, 35));
+		closeButton.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
-				result = usbDevices.get(combo.getText());
+				if (combo.getSelectionIndex() == -1) 
+					result = usbDevices.get(combo.getItems()[0]);
+				else
+					result = usbDevices.get(combo.getItems()[combo.getSelectionIndex()]);
 				shell.dispose();
 			}
 		});
+		shell.pack();
 	}
 }
