@@ -41,7 +41,16 @@ import gde.utils.StringHelper;
 
 
 public enum Transmitter {
-	MC_32("mc-32"), MC_28("mc-28"), MC_26("mc-26"), MC_20("mc-20"), MX_20("mx-20"), MC_16("mc-16"), MX_16("mx-16"), MX_12("mx-12"), UNSPECIFIED("unspecified");
+	MC_32("mc-32", 13, "             ", 86, 120), 
+	MC_28("mc-28", 10, "          ", 126, 120), 
+	MC_26("mc-26", 10, "          ", 126, 120), 
+	MC_20("mc-20", 10, "          ", 195, 24), 
+	MC_16("mc-16", 10, "          ", 195, 24),  
+	MX_20("mx-20", 10, "          ", 177, 24), 
+	MX_16("mx-16", 9, "         ", 53, 20), 
+	MX_12("mx-12", 9, "         ", 53, 10), 
+	MZ_12pro("mz12pro", 9, "         ", 302, 250), 
+	UNSPECIFIED("unspecified",10, "          ", -1, -1);
 
 	final static Logger						log	= Logger.getLogger(Transmitter.class.getName());
 
@@ -53,6 +62,27 @@ public enum Transmitter {
 	public final static byte[] mc_16_PROD_CODE 		=  new byte[] {(byte) 0xF8, 0x35, (byte) 0xF4, 0x00, (byte) 0x09, 0x03, 0x00, 0x00};
 	public final static byte[] mx_16_PROD_CODE		=  new byte[] {(byte) 0xe4, 0x30, (byte) 0xf4, 0x00, (byte) 0xb3, 0x06, 0x00, 0x00};
 	public final static byte[] mx_12_PROD_CODE 		=  new byte[] {(byte) 0x10, 0x32, (byte) 0xf4, 0x00, (byte) 0x73, 0x06, 0x00, 0x00};
+	public final static byte[] mz_12pro_PROD_CODE =  new byte[] {(byte) 0x78, 0x42, (byte) 0xf4, 0x00, (byte) 0x0F, 0x04, 0x00, 0x00};
+	
+//	#define PRODUCT_ID_MX12			16003600
+//	#define PRODUCT_ID_MX16			16003300
+//	#define PRODUCT_ID_MX20			16003700
+//	#define PRODUCT_ID_MC32			16004100
+//	#define PRODUCT_ID_MC20			16004300
+//	#define PRODUCT_ID_MC16			16004600
+//	#define PRODUCT_ID_X8N			16006200
+//	#define PRODUCT_ID_X8E			16006500
+//	#define PRODUCT_ID_MC26			16007700
+//	#define PRODUCT_ID_MC28			16007100
+//	#define PRODUCT_ID_MZ12PRO	16007800
+//
+//	#define MZ_SERIESE_APP_NO_BACKUP
+//	#define MZ24_PCODE					16005200
+//	#define MZ24PRO_PCODE				16007200
+//	#define MZ18_PCODE					16005300
+//	#define X8E_PCODE						16006500
+
+//	mc-28 B4 5C 01 02 30, mc-26 B4 5C 01 0C 30, mz-12pro FC A1 00 00 50
 	
 	public final static byte[] mc_32_APP_VERSION 	=  new byte[] {(byte) 0xe8, 0x03, 0x00, 0x00};
 	public final static byte[] mc_28_APP_VERSION 	=  new byte[] {(byte) 0xea, 0x03, 0x00, 0x00};
@@ -62,6 +92,7 @@ public enum Transmitter {
 	public final static byte[] mc_16_APP_VERSION 	=  new byte[] {(byte) 0xea, 0x03, 0x00, 0x00};
 	public final static byte[] mx_16_APP_VERSION 	=  new byte[] {(byte) 0xe9, 0x03, 0x00, 0x00};
 	public final static byte[] mx_12_APP_VERSION 	=  new byte[] {(byte) 0xe9, 0x03, 0x00, 0x00};
+	public final static byte[] mx_12pro_APP_VERSION= new byte[] {(byte) 0xEA, 0x03, 0x00, 0x00};
 
 	public final static byte[] MEMORY_VERSION 		=  new byte[] {(byte) 0xff,(byte) 0xff,(byte) 0xff,(byte) 0xff,(byte) 0xff,(byte) 0xff,(byte) 0xff,(byte) 0xff};
 
@@ -82,14 +113,34 @@ public enum Transmitter {
 	public final static int[]		mc_32_20_0x21C2					= new int[] { 0x224A, 0x2272, 0x229A, 0x22C2, 0x22EA, 0x2312, 0x233A, 0x2362 };
 
 	private final String	value;
+	private final int mdlNameLength;
+	private final String	noname;
+	private final int startIndex;
+	private final int numMdls;
 	
-	private Transmitter(String v) {
+	private Transmitter(String v, int modelNameLength, String noname, int startIndex, int numMdls) {
 		this.value = v;
+		this.mdlNameLength = modelNameLength;
+		this.noname = noname;
+		this.startIndex = startIndex;
+		this.numMdls = numMdls;
 	}
 
-	public String value() {
+	public String getName() {
 		return this.value;
 	}
+	public int getMdlNameLength() {
+		return this.mdlNameLength;
+	}
+	public String getNoName() {
+		return this.noname;
+	}
+	public int getStartIndex() {
+		return this.startIndex;
+	}
+	public int getNumMdls() {
+		return this.numMdls;
+	}
 
   public static Transmitter fromValue(String v) {
     for (Transmitter c: Transmitter.values()) {
@@ -97,7 +148,7 @@ public enum Transmitter {
             return c;
         }
     }
-    throw new IllegalArgumentException(v);
+    throw new IllegalArgumentException("Unknown transmitter radio " + v);
 }
 
 	/**
@@ -110,7 +161,7 @@ public enum Transmitter {
 		DataInputStream in = null;
 		
 		try {
-			in = new DataInputStream( new FileInputStream(new File(fqPathName)));
+			in = new DataInputStream( new FileInputStream(new File(fqPathName, fileName)));
 			in.read(inBytes);
 			in.close();
 		}
@@ -141,7 +192,7 @@ public enum Transmitter {
 			result = isMC32 ? Transmitter.MC_32 : Transmitter.UNSPECIFIED;
 		}
 		else if ((inBytes[0x08]&0xFF) == 0xEA) {
-			boolean isMC28 = true, isMC26 = true, isMC20 = true, isMX20 = true, isMC16 = true;
+			boolean isMC28 = true, isMC26 = true, isMC20 = true, isMX20 = true, isMC16 = true, isMZ12Pro = true;
 			for (int i = 0; i < 2; i++) {
 				if (inBytes[i] != Transmitter.mc_28_PROD_CODE[i]) {
 					isMC28 = false;
@@ -172,7 +223,13 @@ public enum Transmitter {
 					break;
 				}
 			}
-			result = isMC28 ? Transmitter.MC_28 : isMC26 ? Transmitter.MC_26 : isMC20 ? Transmitter.MC_20 : isMX20 ? Transmitter.MX_20 : isMC16 ? Transmitter.MC_16 : Transmitter.UNSPECIFIED;
+			for (int i = 0; i < 2; i++) {
+				if ((inBytes[0x00 + i]&0xFF) != (Transmitter.mz_12pro_PROD_CODE[i]&0xFF)){
+					isMZ12Pro = false;
+					break;
+				}
+			}
+			result = isMC28 ? Transmitter.MC_28 : isMC26 ? Transmitter.MC_26 : isMC20 ? Transmitter.MC_20 : isMX20 ? Transmitter.MX_20 : isMC16 ? Transmitter.MC_16 : isMZ12Pro ? Transmitter.MZ_12pro : Transmitter.UNSPECIFIED;
 		}
 		else if ((inBytes[0x08]&0xFF) == 0xE9) {
 			boolean isMX16 = true, isMX12 = true;
@@ -190,6 +247,7 @@ public enum Transmitter {
 			}
 			result = isMX16 ? Transmitter.MX_16 : isMX12 ? Transmitter.MX_12 : Transmitter.UNSPECIFIED;
 		}
+		log.log(Level.INFO, "detected Tx " + result.name());
 		return result;
 	}
 
@@ -209,7 +267,7 @@ public enum Transmitter {
 			File inputFile = new File(filepath);
 			in = new DataInputStream( new FileInputStream(inputFile));
 			String outFilePath = filepath.substring(0, filepath.lastIndexOf(GDE.CHAR_FILE_SEPARATOR_UNIX));
-			outFilePath = outFilePath.substring(0, outFilePath.lastIndexOf(GDE.CHAR_FILE_SEPARATOR_UNIX)+1) + targetTransmitter.value() + GDE.STRING_FILE_SEPARATOR_UNIX;
+			outFilePath = outFilePath.substring(0, outFilePath.lastIndexOf(GDE.CHAR_FILE_SEPARATOR_UNIX)+1) + targetTransmitter.getName() + GDE.STRING_FILE_SEPARATOR_UNIX;
 			FileUtils.checkDirectoryAndCreate(outFilePath);
 			outFilePath = outFilePath+ inputFile.getName();
 			File outputFile = new File(outFilePath);
@@ -219,7 +277,7 @@ public enum Transmitter {
 
 			switch (targetTransmitter) {
 			case MC_32:
-				if (log.isLoggable(Level.FINE)) System.out.println("to " + MC_32.value());
+				if (log.isLoggable(Level.FINE)) System.out.println("to " + MC_32.getName());
 				cleanReceiverBinding(bytes);
 				
 				switch (detectSourceTransmitter(bytes)) {
@@ -246,7 +304,7 @@ public enum Transmitter {
 				break;
 				
 			case MC_28:
-				if (log.isLoggable(Level.FINE)) System.out.println("to " + MC_28.value());
+				if (log.isLoggable(Level.FINE)) System.out.println("to " + MC_28.getName());
 				cleanReceiverBinding(bytes);
 
 				switch (detectSourceTransmitter(bytes)) {
@@ -287,7 +345,7 @@ public enum Transmitter {
 				break;
 				
 			case MC_26:
-				if (log.isLoggable(Level.FINE)) System.out.println("to " + MC_26.value());
+				if (log.isLoggable(Level.FINE)) System.out.println("to " + MC_26.getName());
 				cleanReceiverBinding(bytes);
 
 
@@ -329,7 +387,7 @@ public enum Transmitter {
 				break;
 				
 			case MX_20:
-				if (log.isLoggable(Level.FINE)) System.out.println("to " + MX_20.value());			
+				if (log.isLoggable(Level.FINE)) System.out.println("to " + MX_20.getName());			
 				cleanReceiverBinding(bytes);
 								
 				switch (detectSourceTransmitter(bytes)) {
@@ -370,7 +428,7 @@ public enum Transmitter {
 				break;
 				
 			case MC_20:
-				if (log.isLoggable(Level.FINE)) System.out.println("to " + MC_20.value());
+				if (log.isLoggable(Level.FINE)) System.out.println("to " + MC_20.getName());
 				cleanReceiverBinding(bytes);
 
 				switch (detectSourceTransmitter(bytes)) {
@@ -411,7 +469,7 @@ public enum Transmitter {
 				break;
 
 			case MC_16:
-				if (log.isLoggable(Level.FINE)) System.out.println("to " + MC_16.value());
+				if (log.isLoggable(Level.FINE)) System.out.println("to " + MC_16.getName());
 				cleanReceiverBinding(bytes);
 
 				switch (detectSourceTransmitter(bytes)) {
