@@ -133,13 +133,16 @@ public class IGCReaderWriter {
 		StringBuilder gpsTriangleRelated = new StringBuilder();
 		String date = "000000", time; //16 02 40
 		int hour, minute, second;
+		int year, month, day;
 		int latitude, longitude, altBaro, altGPS;
 		int lastLatitude = 0, lastLongitude = 0, lastAltBaro = 0, lastAltGPS = 0;
 		int values[] = new int[device.getNumberOfMeasurements(1)-2]; //climb and speed will be calculated
 		File inputFile = new File(filePath);
 		String dllID = "XXX";
-		IgcExtension timeStepExtension = null;
-		Vector<IgcExtension> extensions = new Vector<IgcExtension>();
+		IgcExtension bTimeStepExtension = null;
+		IgcExtension kTimeStepExtension = null;
+		Vector<IgcExtension> bExtensions = new Vector<IgcExtension>();
+		Vector<IgcExtension> kExtensions = new Vector<IgcExtension>();
 		GDE.getUiNotification().setProgress(0);
 		
 		GpsTaskResult result = null;
@@ -210,15 +213,30 @@ public class IGCReaderWriter {
 						dllID = line.substring(1, 4);
 						log.log(Level.FINE, "IGCDLL iddentifier = " + dllID);
 					}
-					else if (line.startsWith("I")) { // extension specification record
+					else if (line.startsWith("I")) { // B extension specification record
 						try {
 							final int numExtensions = Integer.parseInt(line.substring(1, 3));
 							for (int i = 0; i < numExtensions; i++) {
 								IgcExtension extension = new IgcExtension(Integer.parseInt(line.substring(7 * i + 3, 7 * i + 5))-1, Integer.parseInt(line.substring(7 * i + 5, 7 * i + 7)), line.substring(7 * i + 7, 7 * i + 10));
 								if (extension.getThreeLetterCode().equals("TDS") || extension.getThreeLetterCode().equals("SUS") )
-									timeStepExtension = extension;
+									bTimeStepExtension = extension;
 								else
-									extensions.add(extension);
+									bExtensions.add(extension);
+							}
+						}
+						catch (Exception e) {
+							log.log(Level.SEVERE, e.getMessage(), e);
+						}
+					}
+					else if (line.startsWith("J")) { // K extension specification record
+						try {
+							final int numExtensions = Integer.parseInt(line.substring(1, 3));
+							for (int i = 0; i < numExtensions; i++) {
+								IgcExtension extension = new IgcExtension(Integer.parseInt(line.substring(7 * i + 3, 7 * i + 5))-1, Integer.parseInt(line.substring(7 * i + 5, 7 * i + 7)), line.substring(7 * i + 7, 7 * i + 10));
+								if (extension.getThreeLetterCode().equals("TDS") || extension.getThreeLetterCode().equals("SUS") )
+									kTimeStepExtension = extension;
+								else
+									kExtensions.add(extension);
 							}
 						}
 						catch (Exception e) {
@@ -234,9 +252,6 @@ public class IGCReaderWriter {
 				}
 
 				//calculate the start time stamp using the first B record
-				int year;
-				int month;
-				int day;
 				if (date.contains(":")) {
 					int startIndex = date.indexOf(":");
 					year = Integer.parseInt(date.substring(startIndex+5, startIndex+7)) + 2000;
@@ -265,12 +280,11 @@ public class IGCReaderWriter {
 				minute = Integer.parseInt(time.substring(2, 4));
 				second = Integer.parseInt(time.substring(4, 6));
 				startTimeStamp = new GregorianCalendar(year, month - 1, day, hour, minute, second).getTimeInMillis();
-				if (timeStepExtension != null) {
-					startTimeStamp += Long.parseLong(line.substring(timeStepExtension.start, timeStepExtension.end));
+				if (bTimeStepExtension != null) {
+					startTimeStamp += Long.parseLong(line.substring(bTimeStepExtension.start, bTimeStepExtension.end));
 				}
 					
 
-
 				//parse B records B160240 5407121N 00249342W A 00280 00421
 				do {
 					lastLine = line = line.trim();
@@ -283,9 +297,10 @@ public class IGCReaderWriter {
 						minute = Integer.parseInt(time.substring(2, 4));
 						second = Integer.parseInt(time.substring(4, 6));
 						actualTimeStamp = new GregorianCalendar(year, month - 1, day, hour, minute, second).getTimeInMillis();
-						if (timeStepExtension != null) {
-							actualTimeStamp += Long.parseLong(line.substring(timeStepExtension.start, timeStepExtension.end));
+						if (bTimeStepExtension != null) {
+							actualTimeStamp += Long.parseLong(line.substring(bTimeStepExtension.start, bTimeStepExtension.end));
 						}
+						
 
 						int progress = (int) (lineNumber * 100 / approximateLines);
 						if (progress % 5 == 0) GDE.getUiNotification().setProgress(progress);
@@ -335,14 +350,20 @@ public class IGCReaderWriter {
 							//values[4] = climb calculated;
 							//values[5] = speed calculated;
 							int i=0;
-							for (IgcExtension extension : extensions) {
+							for (IgcExtension extension : bExtensions) {
 								if (recordSet.realSize() > 6+i && !recordSet.get(6+i).getName().equals(extension.getThreeLetterCode())) {
-									if (log.isLoggable(Level.FINE)) log.log(Level.FINE, String.format("set record with name %s # %d to name %s", recordSet.get(6+i).getName(), 6+i, extension.getThreeLetterCode()));
+									if (log.isLoggable(Level.INFO)) log.log(Level.INFO, String.format("set record with name %s # %d to name %s", recordSet.get(6+i).getName(), 6+i, extension.getThreeLetterCode()));
+									recordSet.get(6+i).setName(extension.getThreeLetterCode());
+								}
+								++i;
+							}
+							for (IgcExtension extension : kExtensions) {
+								if (recordSet.realSize() > 6+i && !recordSet.get(6+i).getName().equals(extension.getThreeLetterCode())) {
+									if (log.isLoggable(Level.INFO)) log.log(Level.INFO, String.format("set record with name %s # %d to name %s", recordSet.get(6+i).getName(), 6+i, extension.getThreeLetterCode()));
 									recordSet.get(6+i).setName(extension.getThreeLetterCode());
 								}
 								++i;
 							}
-
 						}
 
 						if (timeStamp < actualTimeStamp) {
@@ -410,8 +431,8 @@ public class IGCReaderWriter {
 							values[2] = altBaro * 1000;
 							values[3] = altGPS * 1000;
 
-							for (int i = 0; i < extensions.size() && i+4 < values.length; i++) {
-								values[i + 4] = extensions.get(i).getValue(line);
+							for (int i = 0; i < bExtensions.size() && i+4 < values.length; i++) {
+								values[i + 4] = bExtensions.get(i).getValue(line);
 							}
 
 							recordSet.addNoneCalculationRecordsPoints(values, actualTimeStamp - startTimeStamp);
@@ -423,6 +444,30 @@ public class IGCReaderWriter {
 								error.append(String.format(Locale.getDefault(), "High time deviation %dms at line %d %s", actualTimeStamp - timeStamp, lineNumber - 1, line)).append(GDE.LINE_SEPARATOR);
 							}
 					}
+					else if (line.startsWith("K")) {
+						log.log(Level.FINE, "K RECORD - Data extensioni = " + line);
+						time = line.substring(1, 7); //16 02 40
+						hour = Integer.parseInt(time.substring(0, 2));
+						minute = Integer.parseInt(time.substring(2, 4));
+						second = Integer.parseInt(time.substring(4, 6));
+						actualTimeStamp = new GregorianCalendar(year, month - 1, day, hour, minute, second).getTimeInMillis();
+						if (kTimeStepExtension != null) {
+							actualTimeStamp += Long.parseLong(line.substring(kTimeStepExtension.start, kTimeStepExtension.end));
+						}
+
+						for (int i = 0; i < kExtensions.size() && i+4+bExtensions.size() < values.length; i++) {
+							values[i + 4 + bExtensions.size()] = kExtensions.get(i).getValue(line);
+							log.log(Level.FINE, String.format("%s = %d", kExtensions.get(i).threeLetterCode, kExtensions.get(i).getValue(line)/1000));
+						}
+						if (actualTimeStamp > timeStamp)
+							recordSet.addNoneCalculationRecordsPoints(values, actualTimeStamp - startTimeStamp);
+						else if (actualTimeStamp == timeStamp) {
+							if (log.isLoggable(Level.INFO))
+								log.log(Level.INFO, String.format("%s at %s ms %s", recordSet.getName(), new SimpleDateFormat("HH:mm:ss.SSS").format(actualTimeStamp), StringHelper.arrayToString1000(values)));
+							recordSet.replaceUpdateNoneCalculationRecordsPoints(values);
+						}
+						timeStamp = actualTimeStamp;
+					}
 					else if (line.startsWith("F")) {
 						//skip F RECORD - SATELLITE CONSTELLATION.
 						log.log(Level.FINE, "F RECORD - SATELLITE CONSTELLATION = " + line);
