@@ -1598,7 +1598,7 @@ public class MC3000 extends DeviceConfiguration implements IDevice {
 
 		if (this.settings.isReduceChargeDischarge() && !this.isContinuousRecordSet()) 
 			return dataBuffer[5] > 0 && dataBuffer[5] < 3;
-		return dataBuffer[5] > 0 && dataBuffer[5] < 4;
+		return dataBuffer[5] > 0 && dataBuffer[5] <= 4;
 	}
 
 	/**
@@ -1627,7 +1627,6 @@ public class MC3000 extends DeviceConfiguration implements IDevice {
 	public String getProcessingStatusName(final byte[] dataBuffer) {
 		return this.isContinuousRecordSet() ? Messages.getString(MessageIds.GDE_MSGT3606) : this.STATUS_MODE[dataBuffer[5]];
 	}
-
 	
 	/**
 	 * @return true if setting is configured to continuous record set data gathering
@@ -1747,6 +1746,13 @@ public class MC3000 extends DeviceConfiguration implements IDevice {
 		return this.systemSettings.getFirmwareVersion();
 	}
 
+	/**
+	 * @return firmware as int
+	 */
+	public int getFirmwareVersionAsInt() {
+		return this.systemSettings.getFirmwareVersionAsInt();
+	}
+
 	/**
 	 * @return string containing system temperatur unit
 	 */
